@@ -13,7 +13,7 @@ use Tree::R;
 use constant ON_WINDOWS => ($^O eq 'MSWin32');
 use if ON_WINDOWS, 'Win32::LongPath';
 
-our $VERSION = '2.99_001';
+our $VERSION = '2.99_002';
 
 my $little_endian_sys = unpack 'b', (pack 'S', 1 );
 
@@ -1136,7 +1136,7 @@ Please send any bugs, suggestions, or feature requests to
 L<Geo::ShapeFile::Shape>, 
 L<Geo::ShapeFile::Point>, 
 L<Geo::Shapefile::Writer>, 
-L<Geo::GDAL>
+L<Geo::GDAL::FFI>
 
 =head1 AUTHOR
 
